@@ -96,11 +96,6 @@ abstract public class MainViewHandler extends HotkeyHandler {
 	}
 
 
-	public boolean isAddingWordsSupported() {
-		return mLanguage == null || !mLanguage.isTranscribed();
-	}
-
-
 	public boolean isDragResizeOn() {
 		return dragResize;
 	}
@@ -138,27 +133,22 @@ abstract public class MainViewHandler extends HotkeyHandler {
 		return InputModeKind.isNumeric(mInputMode);
 	}
 
-
-	public boolean isNumericModeStrict() {
-		return InputModeKind.is123(mInputMode) && inputType.isNumeric() && !inputType.isPhoneNumber();
+	public boolean isInputTypeNumeric() {
+		return inputType.isNumeric();
 	}
 
-
-	public boolean isNumericModeDecimal() {
-		return InputModeKind.is123(mInputMode) && inputType.isDecimal();
+	public boolean isInputTypeDecimal() {
+		return (inputType.isDecimal() || inputType.isUnspecifiedNumber());
 	}
 
-
-	public boolean isNumericModeSigned() {
-		return InputModeKind.is123(mInputMode) && inputType.isSignedNumber();
+	public boolean isInputTypeSigned() {
+		return (inputType.isSignedNumber() || inputType.isUnspecifiedNumber());
 	}
 
-
-	public boolean isInputModePhone() {
-		return InputModeKind.is123(mInputMode) && inputType.isPhoneNumber();
+	public boolean isInputTypePhone() {
+		return inputType.isPhoneNumber();
 	}
 
-
 	public boolean isTextEditingActive() {
 		return mainView != null && mainView.isTextEditingPaletteShown();
 	}
