@@ -1,5 +1,7 @@
 package io.github.sspanak.tt9.preferences.screens.debug;
 
+import androidx.annotation.Nullable;
+
 import io.github.sspanak.tt9.R;
 import io.github.sspanak.tt9.preferences.PreferencesActivity;
 import io.github.sspanak.tt9.preferences.items.ItemText;
@@ -11,8 +13,8 @@ public class DebugScreen extends BaseScreenFragment {
 
 	private static final String DEVICE_INFO_CONTAINER = "pref_device_info";
 
-	public DebugScreen() { init(); }
-	public DebugScreen(PreferencesActivity activity) { init(activity); }
+	public DebugScreen() { super(); }
+	public DebugScreen(@Nullable PreferencesActivity activity) { super(activity); }
 
 	@Override public String getName() { return NAME; }
 	@Override protected int getTitle() { return R.string.pref_category_debug_options; }
