@@ -5,9 +5,13 @@ import android.content.SharedPreferences;
 
 import androidx.preference.PreferenceManager;
 
+import io.github.sspanak.tt9.BuildConfig;
+
 class BaseSettings {
 	protected final String LOG_TAG = SettingsInput.class.getSimpleName();
 
+	private static final String FIRST_INSTALL_VERSION_KEY = "first_install_version";
+
 	protected final Context context;
 	protected final SharedPreferences prefs;
 	private SharedPreferences.Editor prefsEditor;
@@ -16,6 +20,7 @@ class BaseSettings {
 	BaseSettings(Context context) {
 		this.context = context;
 		prefs = PreferenceManager.getDefaultSharedPreferences(context);
+		setFirstInstallVersion();
 	}
 
 	public SharedPreferences.Editor getPrefsEditor() {
@@ -41,4 +46,14 @@ class BaseSettings {
 			return defaultValue;
 		}
 	}
+
+	private void setFirstInstallVersion() {
+		if (prefs.getInt(FIRST_INSTALL_VERSION_KEY, -1) == -1) {
+			getPrefsEditor().putInt(FIRST_INSTALL_VERSION_KEY, BuildConfig.VERSION_CODE).apply();
+		}
+	}
+
+	protected boolean isFirstInstall() {
+		return prefs.getInt(FIRST_INSTALL_VERSION_KEY, BuildConfig.VERSION_CODE) == BuildConfig.VERSION_CODE;
+	}
 }
