@@ -59,11 +59,11 @@ public class SoftKeyNumber0 extends SoftKeyNumberSwipeable {
 
 		if (tt9.isTextEditingActive()) {
 			return "";
-		} else if (tt9.isNumericModeSigned()) {
+		} else if (tt9.isInputTypeSigned()) {
 			return "+/-";
-		} else if (tt9.isInputModePhone()) {
+		} else if (tt9.isInputTypePhone()) {
 			return "+";
-		} else if (tt9.isNumericModeStrict()) {
+		} else if (tt9.isInputTypeNumeric() && !tt9.isInputTypeSigned() && !tt9.isInputTypePhone()) {
 			return "";
 		} else if (tt9.isInputModeNumeric() || hasLettersOnAllKeys()) {
 			return CHARS_NUMERIC_MODE;
@@ -99,7 +99,7 @@ public class SoftKeyNumber0 extends SoftKeyNumberSwipeable {
 
 		// scale up the space character, because it is too small
 		if (Characters.SPACE.equals(getTitle())) {
-			return 1.3f * Math.min(1, getTT9Height()) * getScreenScaleY();
+			return 1.3f * Math.min(1, getTT9Height()) * getScreenSizeScale();
 		}
 
 		return super.getTitleScale();
